@@ -1,20 +1,3 @@
-# -*- coding: utf-8 -*-
-#
-# Copyright (C) 2013-2017 Gauvain Pocentek <gauvain@pocentek.net>
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
 import functools
 from typing import Any, Callable, cast, Optional, Type, TYPE_CHECKING, TypeVar, Union
 
@@ -62,6 +45,10 @@ class GitlabParsingError(GitlabError):
     pass
 
 
+class GitlabCiLintError(GitlabError):
+    pass
+
+
 class GitlabConnectionError(GitlabError):
     pass
 
@@ -246,6 +233,10 @@ class GitlabImportError(GitlabOperationError):
     pass
 
 
+class GitlabInvitationError(GitlabOperationError):
+    pass
+
+
 class GitlabCherryPickError(GitlabOperationError):
     pass
 
@@ -282,6 +273,10 @@ class GitlabRepairError(GitlabOperationError):
     pass
 
 
+class GitlabRestoreError(GitlabOperationError):
+    pass
+
+
 class GitlabRevertError(GitlabOperationError):
     pass
 
